Struct InsertDelta
pub struct InsertDelta<N>(/* private fields */)
where
N: NodeInfo;Expand description
A struct marking that a Delta contains only insertions. That is, it copies
all of the old document in the same order. It has a Deref impl so all
normal Delta methods can also be used on it.
Implementations
impl<N> InsertDelta<N>where
N: NodeInfo,
impl<N> InsertDelta<N>where
N: NodeInfo,
pub fn transform_expand(&self, xform: &Subset, after: bool) -> InsertDelta<N>
pub fn transform_expand(&self, xform: &Subset, after: bool) -> InsertDelta<N>
Do a coordinate transformation on an insert-only delta. The after parameter
controls whether the insertions in self come after those specific in the
coordinate transform.
pub fn transform_shrink(&self, xform: &Subset) -> InsertDelta<N>
pub fn transform_shrink(&self, xform: &Subset) -> InsertDelta<N>
Shrink a delta through a deletion of some of its copied regions with
the same base. For example, if self applies to a union string, and
xform is the deletions from that union, the resulting Delta will
apply to the text.
pub fn inserted_subset(&self) -> Subset
pub fn inserted_subset(&self) -> Subset
Return a Subset containing the inserted ranges.
d.inserted_subset().delete_from_string(d.apply_to_string(s)) == s
Methods from Deref<Target = Delta<N>>
pub fn as_simple_insert(&self) -> Option<&Node<N>>
pub fn as_simple_insert(&self) -> Option<&Node<N>>
If this delta represents a simple insertion, returns the inserted node.
pub fn is_simple_delete(&self) -> bool
pub fn is_simple_delete(&self) -> bool
Returns true if this delta represents a single deletion without
any insertions.
Note that this is false for the trivial delta, as well as for a deletion
from an empty Rope.
pub fn is_identity(&self) -> bool
pub fn is_identity(&self) -> bool
Returns true if applying the delta will cause no change.
pub fn apply(&self, base: &Node<N>) -> Node<N>
pub fn apply(&self, base: &Node<N>) -> Node<N>
Apply the delta to the given rope. May not work well if the length of the rope is not compatible with the construction of the delta.
pub fn summary(&self) -> (Interval, usize)
pub fn summary(&self) -> (Interval, usize)
Produce a summary of the delta. Everything outside the returned interval is unchanged, and the old contents of the interval are replaced by new contents of the returned length. Equations:
(iv, new_len) = self.summary()
new_s = self.apply(s)
new_s = simple_edit(iv, new_s.subseq(iv.start(), iv.start() + new_len), s.len()).apply(s)
pub fn new_document_len(&self) -> usize
pub fn new_document_len(&self) -> usize
Returns the length of the new document. In other words, the length of the transformed string after this Delta is applied.
d.apply(r).len() == d.new_document_len()
pub fn inserts_len(&self) -> usize
pub fn inserts_len(&self) -> usize
Returns the sum length of the inserts of the delta.
pub fn iter_inserts(&self) -> InsertsIter<'_, N> ⓘ
pub fn iter_inserts(&self) -> InsertsIter<'_, N> ⓘ
Iterates over all the inserts of the delta.
pub fn iter_deletions(&self) -> DeletionsIter<'_, N> ⓘ
pub fn iter_deletions(&self) -> DeletionsIter<'_, N> ⓘ
Iterates over all the deletions of the delta.